PAWpySeed: pawpyseed.analysis.defect_composition.PawpyData Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.analysis.defect_composition.PawpyData Class Reference
Inheritance diagram for pawpyseed.analysis.defect_composition.PawpyData:
[legend]

## Public Member Functions
def | __init__ (self, structure, data, dos=None, vbm=None, cbm=None)
def | set_band_properties (vbm, cbm)
def | as_dict (self)
def | write_yaml (self, filename)
def | from_dict (cls, data)
def | from_yaml (cls, filename)

## Public Attributes
| energies
| densities
| efermi
| structure
| data
| cbm
| vbm
| bandgap

## Constructor & Destructor Documentation

def pawpyseed.analysis.defect_composition.PawpyData.__init__ | ( |  | self,
|  |  | structure,
|  |  | data,
|  |  | dos = `None`,
|  |  | vbm = `None`,
|  |  | cbm = `None`
| ) |  |

    Arguments:
        structure (pymatgen.core.structure.Structure): crystal structure
        data: Whatever data is stored
        dos (pymatgen.electronic_structure.dos.DOS or list, None): A pymatgen
    density of states or a list containing: 1) energies, 2) density
    of states values at those energies, 3) the Fermi level.
        vbm (float, None): valence band maximum
        cbm (float, None): conduction band minimum

## Member Function Documentation

def pawpyseed.analysis.defect_composition.PawpyData.as_dict | ( |  | self | ) |

    Returns a representation of the PawpyData
    as a dictionary.

def pawpyseed.analysis.defect_composition.PawpyData.from_dict | ( |  | cls,
|  |  | data
| ) |  |

    Takes the dictionary--data--and
    returns a PawpyData instance.

def pawpyseed.analysis.defect_composition.PawpyData.from_yaml | ( |  | cls,
|  |  | filename
| ) |  |

    Reads a PawpyData instance from
    a file called filename.

def pawpyseed.analysis.defect_composition.PawpyData.set_band_properties | ( |  | vbm,
|  |  | cbm
| ) |  |

    Set the VBM, CBM, and band gap.

    Arguments:
        vbm (float): valence band maximum
        cbm (float): conduction band minimum

def pawpyseed.analysis.defect_composition.PawpyData.write_yaml | ( |  | self,
|  |  | filename
| ) |  |

    Write the PawpyData as a yaml file
    called filename

## Member Data Documentation

pawpyseed.analysis.defect_composition.PawpyData.bandgap

pawpyseed.analysis.defect_composition.PawpyData.cbm

pawpyseed.analysis.defect_composition.PawpyData.data

pawpyseed.analysis.defect_composition.PawpyData.densities

pawpyseed.analysis.defect_composition.PawpyData.efermi

pawpyseed.analysis.defect_composition.PawpyData.energies

pawpyseed.analysis.defect_composition.PawpyData.structure

pawpyseed.analysis.defect_composition.PawpyData.vbm

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/defect_composition.py